@@ -7,6 +7,8 @@
 
 #include <cstddef>
 #include <cstdint>
+#include <memory>
+#include <ostream>
 
 #include "sslt.h"
 
@@ -46,4 +48,7 @@ class ServerConfig {
   SSLVersionRange ssl_version_range_;
 };
 
+std::ostream& operator<<(std::ostream& out,
+                         std::unique_ptr<ServerConfig>& config);
+
 #endif  // TLS_SERVER_CONFIG_H_
